<?php
/*
 * Plugin Name: SideMenu Premium
 * Version: 1.0.2
 * Plugin URI: https://webd.uk/sidemenu/
 * Description: Adds even more options to the SideMenu
 * Author: webd.uk
 * Author URI: https://webd.uk
 */



if (!defined('ABSPATH')) {
    exit('This isn\'t the page you\'re looking for. Move along, move along.');
}



if (!class_exists('sidemenu_premium_class')) {

	class sidemenu_premium_class {

        public static $version = '1.0.2';

		function __construct() {

            add_action('customize_register', array($this, 'sidemenu_customize_register'), 999);
            add_action('wp_head' , array($this, 'sidemenu_header_output'), 11);

            if (is_admin()) {

                add_filter('pre_set_site_transient_update_plugins', 'sidemenuPremium::check_plugin_update');
                add_filter('plugins_api', 'sidemenuPremium::get_plugin_information', 10, 3);
                add_filter('plugin_action_links_' . plugin_basename(__FILE__), array($this, 'sidemenu_add_plugin_action_links'));
                add_filter('after_plugin_row_' . plugin_basename(__FILE__), 'sidemenuPremium::activate_purchase_js', 10, 3);
                add_action('wp_ajax_sidemenu_activate_purchase', 'sidemenuPremium::activate_purchase');
                add_action('admin_notices', 'sidemenuPremium::upgrade_notice');

            }

            add_action('init', 'sidemenuPremium::schedule_check');
            add_action('sidemenu_check', 'sidemenuPremium::scheduled_check');

		}

		function sidemenu_add_plugin_action_links($links) {

			$settings_links = sidemenuCommon::plugin_action_links(add_query_arg('autofocus[section]', 'sidemenu', admin_url('customize.php')), true);

			return array_merge($settings_links, $links);

		}

        function sidemenu_customize_register($wp_customize) {

            if (!class_exists('reset_customizer_class')) {

                $wp_customize->add_section('reset_customizer', array(
                    'title'     => __('Reset Customizer', 'reset-customizer'),
                    'description'  => __('Reset Customizer allows you to reset the options within each section of the customizer to their defaults without affecting other settings. You can also backup, delete and restore entire sets of customizer theme mods.', 'sidemenu'),
                    'priority'     => 0
                ));

                sidemenuCommon::add_hidden_control($wp_customize, 'install_reset_customizer', 'reset_customizer', '', sprintf(wp_kses(__('<a href="%s" class="button-primary">Install Reset Customizer plugin</a>.', 'sidemenu'), array('a' => array('href' => array(), 'class' => array()))), esc_url(wp_nonce_url(add_query_arg(array('action' => 'install-plugin', 'plugin' => 'reset-customizer'), self_admin_url('update.php')), 'install-plugin_reset-customizer'))));

            }



            $upgrade_link = '<a href="' . sidemenuCommon::upgrade_link() . '" title="' . __('Upgrade to SideMenu Premium', 'sidemenu') . '">' . __('Upgrade to SideMenu Premium', 'sidemenu') . '</a>';
            $upgrade_nag = $upgrade_link . __(' to activate this option.', 'sidemenu');



            if (file_exists(ABSPATH . WPINC . '/css/dashicons.css')) {

                $dashicons_css = explode("\n", implode('', file(ABSPATH . WPINC . '/css/dashicons.css')));
                $dashicons = array();

                foreach ($dashicons_css as $css_entry) {

                    if (strlen($css_entry) > 10 && substr($css_entry, 0, 11) === '.dashicons-') {

                        $dashicon_class = sanitize_key(preg_replace(array('/^.dashicons-/', '/:before {$/'), '', $css_entry));
                        $dashicons[$dashicon_class] = __(ucwords(str_replace('-', ' ', $dashicon_class)), 'sidemenu');

                    }

                }

                asort($dashicons);

                $control_label = __('Dashicon', 'sidemenu');
                $control_description = sprintf(wp_kses(__('Choose your own <a href="%s">dashicon</a> for the button that opens the SideMenu.', 'sidemenu'), array('a' => array('href' => array()))), esc_url('https://developer.wordpress.org/resource/dashicons/'));

                if (sidemenuPremium::request_permission()) {

                    $wp_customize->add_setting('sidemenu_dashicon', array(
                        'default'       => 'menu-alt',
                        'type'          => 'theme_mod',
                        'transport'     => 'refresh',
                        'sanitize_callback' => 'sidemenuCommon::sanitize_options'
                    ));
                    $wp_customize->add_control('sidemenu_dashicon', array(
                        'label'         => $control_label,
                        'description'   => $control_description,
                        'section'       => 'sidemenu',
                        'settings'      => 'sidemenu_dashicon',
                        'type'          => 'select',
                        'choices'       => $dashicons
                    ));

                } else {

                    sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_dashicon', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

                }

            }

            $control_label = __('Overlay Color', 'sidemenu');
            $control_description = __('Set the background color of the overlay that dims the main website.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_overlay_color', array(
                    'default'       => '#000000',
                    'type'          => 'theme_mod',
                    'transport'     => 'postMessage',
                    'sanitize_callback' => 'sanitize_hex_color'
                ));
                $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'sidemenu_overlay_color', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                	'settings'      => 'sidemenu_overlay_color'
                )));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_overlay_color', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('Overlay Opacity', 'sidemenu');
            $control_description = __('Set the opacity of the overlay that dims the main website.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_overlay_opacity', array(
                    'default'       => '7',
                    'type'          => 'theme_mod',
                    'transport'     => 'postMessage',
                    'sanitize_callback' => 'absint'
                ));
                $wp_customize->add_control('sidemenu_overlay_opacity', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                    'settings'      => 'sidemenu_overlay_opacity',
                    'type'          => 'range',
                    'input_attrs' => array(
                        'min'   => 1,
                        'max'   => 11,
                        'step'  => 1
                    )
                ));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_overlay_opacity', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('SideMenu Width', 'sidemenu');
            $control_description = __('Set the width of the SideMenu.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_width', array(
                    'default'       => '45',
                    'type'          => 'theme_mod',
                    'transport'     => 'refresh',
                    'sanitize_callback' => 'absint'
                ));
                $wp_customize->add_control('sidemenu_width', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                    'settings'      => 'sidemenu_width',
                    'type'          => 'range',
                    'input_attrs' => array(
                        'min'   => 30,
                        'max'   => 100,
                        'step'  => 5
                    )
                ));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_width', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('SideMenu Background Color', 'sidemenu');
            $control_description = __('Set the background color of the SideMenu.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_background_color', array(
                    'default'       => '#666666',
                    'type'          => 'theme_mod',
                    'transport'     => 'postMessage',
                    'sanitize_callback' => 'sanitize_hex_color'
                ));
                $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'sidemenu_background_color', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                	'settings'      => 'sidemenu_background_color'
                )));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_background_color', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('SideMenu Title Alignment', 'sidemenu');
            $control_description = __('Align the titles in the SideMenu to the left, center or right.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_title_text_align', array(
                    'default'       => '',
                    'type'          => 'theme_mod',
                    'transport'     => 'postMessage',
                    'sanitize_callback' => 'sidemenuCommon::sanitize_options'
                ));
                $wp_customize->add_control('sidemenu_title_text_align', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                    'settings'      => 'sidemenu_title_text_align',
                    'type'          => 'select',
                    'choices'       => array(
                        '' => __('Left', 'sidemenu'),
                        'center' => __('Center', 'sidemenu'),
                        'right' => __('Right', 'sidemenu')
                    )
                ));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_title_text_align', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('SideMenu Title Font Case', 'sidemenu');
            $control_description = __('Change the font case of the titles in the SideMenu.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_title_text_transform', array(
                    'default'       => '',
                    'type'          => 'theme_mod',
                    'transport'     => 'postMessage',
                    'sanitize_callback' => 'sidemenuCommon::sanitize_options'
                ));
                $wp_customize->add_control('sidemenu_title_text_transform', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                    'settings'      => 'sidemenu_title_text_transform',
                    'type'          => 'select',
                    'choices'       => array(
                        '' => __('None', 'sidemenu'),
                        'capitalize' => __('Capitalise', 'sidemenu'),
                        'uppercase' => __('Uppercase', 'sidemenu'),
                        'lowercase' => __('Lowercase', 'sidemenu')
                    )
                ));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_title_text_transform', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('SideMenu Title Font Size', 'sidemenu');
            $control_description = __('Change the font size of the titles in the SideMenu.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_title_font_size', array(
                    'default'       => '15',
                    'type'          => 'theme_mod',
                    'transport'     => 'postMessage',
                    'sanitize_callback' => 'absint'
                ));
                $wp_customize->add_control('sidemenu_title_font_size', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                    'settings'      => 'sidemenu_title_font_size',
                    'type'          => 'range',
                    'input_attrs' => array(
                        'min'   => 5,
                        'max'   => 30,
                        'step'  => 1
                    )
                ));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_title_font_size', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('SideMenu Title Font Weight', 'sidemenu');
            $control_description = __('Change the font weight of the titles in the SideMenu.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_title_font_weight', array(
                    'default'       => '700',
                    'type'          => 'theme_mod',
                    'transport'     => 'postMessage',
                    'sanitize_callback' => 'absint'
                ));
                $wp_customize->add_control('sidemenu_title_font_weight', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                    'settings'      => 'sidemenu_title_font_weight',
                    'type'          => 'range',
                    'input_attrs' => array(
                        'min'   => 100,
                        'max'   => 900,
                        'step'  => 100
                    )
                ));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_title_font_weight', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('SideMenu Title Color', 'sidemenu');
            $control_description = __('Set the color of titles in the SideMenu.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_title_color', array(
                    'default'       => '#ffffff',
                    'type'          => 'theme_mod',
                    'transport'     => 'postMessage',
                    'sanitize_callback' => 'sanitize_hex_color'
                ));
                $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'sidemenu_title_color', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                	'settings'      => 'sidemenu_title_color'
                )));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_title_color', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('SideMenu Text Font Size', 'sidemenu');
            $control_description = __('Change the font size of the text in the SideMenu.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_text_font_size', array(
                    'default'       => '10',
                    'type'          => 'theme_mod',
                    'transport'     => 'postMessage',
                    'sanitize_callback' => 'absint'
                ));
                $wp_customize->add_control('sidemenu_text_font_size', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                    'settings'      => 'sidemenu_text_font_size',
                    'type'          => 'range',
                    'input_attrs' => array(
                        'min'   => 5,
                        'max'   => 20,
                        'step'  => 1
                    )
                ));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_text_font_size', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('SideMenu Text Color', 'sidemenu');
            $control_description = __('Set the color of text in the SideMenu.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_text_color', array(
                    'default'       => '#ffffff',
                    'type'          => 'theme_mod',
                    'transport'     => 'postMessage',
                    'sanitize_callback' => 'sanitize_hex_color'
                ));
                $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'sidemenu_text_color', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                	'settings'      => 'sidemenu_text_color'
                )));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_text_color', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('SideMenu Link Color', 'sidemenu');
            $control_description = __('Set the color of links in the SideMenu.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_link_color', array(
                    'default'       => '#d3d3d3',
                    'type'          => 'theme_mod',
                    'transport'     => 'postMessage',
                    'sanitize_callback' => 'sanitize_hex_color'
                ));
                $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'sidemenu_link_color', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                	'settings'      => 'sidemenu_link_color'
                )));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_link_color', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('SideMenu Link Hover Color', 'sidemenu');
            $control_description = __('Set the color of hovered links in the SideMenu.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_link_hover_color', array(
                    'default'       => '#000000',
                    'type'          => 'theme_mod',
                    'transport'     => 'refresh',
                    'sanitize_callback' => 'sanitize_hex_color'
                ));
                $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'sidemenu_link_hover_color', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                	'settings'      => 'sidemenu_link_hover_color'
                )));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_link_hover_color', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('Section Border Width', 'sidemenu');
            $control_description = __('Set the width of the border inbetween sections in the SideMenu.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_section_border_width', array(
                    'default'       => '2',
                    'type'          => 'theme_mod',
                    'transport'     => 'refresh',
                    'sanitize_callback' => 'absint'
                ));
                $wp_customize->add_control('sidemenu_section_border_width', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                    'settings'      => 'sidemenu_section_border_width',
                    'type'          => 'range',
                    'input_attrs' => array(
                        'min'   => 1,
                        'max'   => 11,
                        'step'  => 1
                    )
                ));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_section_border_width', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('Section Border Color', 'sidemenu');
            $control_description = __('Set the color of the border inbetween sections in the SideMenu.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_section_border_color', array(
                    'default'       => '',
                    'type'          => 'theme_mod',
                    'transport'     => 'refresh',
                    'sanitize_callback' => 'sanitize_hex_color'
                ));
                $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'sidemenu_section_border_color', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                	'settings'      => 'sidemenu_section_border_color'
                )));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_section_border_color', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

            $control_label = __('Section Border Style', 'sidemenu');
            $control_description = __('Set the style of the border inbetween sections in the SideMenu.', 'sidemenu');

            if (sidemenuPremium::request_permission()) {

                $wp_customize->add_setting('sidemenu_section_border_style', array(
                    'default'       => '',
                    'type'          => 'theme_mod',
                    'transport'     => 'refresh',
                    'sanitize_callback' => 'sidemenuCommon::sanitize_options'
                ));
                $wp_customize->add_control('sidemenu_section_border_style', array(
                    'label'         => $control_label,
                    'description'   => $control_description,
                    'section'       => 'sidemenu',
                    'settings'      => 'sidemenu_section_border_style',
                    'type'          => 'select',
                    'choices'       => array(
                        'dotted' => __('Dotted', 'sidemenu'),
                        'dashed' => __('Dashed', 'sidemenu'),
                        '' => __('Solid', 'sidemenu'),
                        'double' => __('Double', 'sidemenu'),
                        'groove' => __('3D Groove', 'sidemenu'),
                        'ridge' => __('3D Ridge', 'sidemenu'),
                        'inset' => __('3D Inset', 'sidemenu'),
                        'outset' => __('3D Outset', 'sidemenu')
                    )
                ));

            } else {

                sidemenuCommon::add_hidden_control($wp_customize, 'sidemenu_section_border_style', 'sidemenu', $label = $control_label, $control_description . ' ' . $upgrade_nag);

            }

        }

        function sidemenu_header_output() {

?>
<!--Customizer CSS-->
<style type="text/css">
<?php

if (sidemenuPremium::request_permission()) {

            $mod = absint(get_theme_mod('sidemenu_overlay_opacity'));

            if ($mod) {

                $mod = ($mod - 1) / 10;

?>
.sidemenu_open>.cover {
    opacity: <?= $mod; ?>;
}
<?php

            }

            $sidemenu_width = get_theme_mod('sidemenu_width');

            if (absint($sidemenu_width)) {

                if (get_theme_mod('sidemenu_position')) {

?>
@media screen and (min-width: 48em) {
    .sidemenu {
        left: -<?= absint($sidemenu_width); ?>%;
        width: <?= absint($sidemenu_width); ?>%;
    }
}
.sidemenu_open>div {
    transform: translateX(<?= absint($sidemenu_width / 2); ?>%);
}
<?php

                } else {
                
?>
@media screen and (min-width: 48em) {
    .sidemenu {
        right: -<?= absint($sidemenu_width); ?>%;
        width: <?= absint($sidemenu_width); ?>%;
    }
}
.sidemenu_open>div {
    transform: translateX(-<?= absint($sidemenu_width / 2); ?>%);
}
<?php

                }

            }

            sidemenuCommon::generate_css('body>.cover', 'background-color', 'sidemenu_overlay_color');
            sidemenuCommon::generate_css('.sidemenu', 'background-color', 'sidemenu_background_color');
            sidemenuCommon::generate_css('.sidemenu section h2', 'text-align', 'sidemenu_title_text_align');
            sidemenuCommon::generate_css('.sidemenu section h2', 'text-transform', 'sidemenu_title_text_transform');
            sidemenuCommon::generate_css('.sidemenu section h2', 'font-size', 'sidemenu_title_font_size', '', 'em', (get_theme_mod('sidemenu_title_font_size') ? (absint(get_theme_mod('sidemenu_title_font_size')) / 10) : ''));
            sidemenuCommon::generate_css('.sidemenu section h2', 'font-weight', 'sidemenu_title_font_weight');
            sidemenuCommon::generate_css('.sidemenu section h2', 'color', 'sidemenu_title_color');
            sidemenuCommon::generate_css('.sidemenu p, .sidemenu li', 'font-size', 'sidemenu_text_font_size', '', 'em', (get_theme_mod('sidemenu_text_font_size') ? (absint(get_theme_mod('sidemenu_text_font_size')) / 10) : ''));
            sidemenuCommon::generate_css('.sidemenu', 'color', 'sidemenu_text_color');
            sidemenuCommon::generate_css('.sidemenu section a', 'color', 'sidemenu_link_color');
            sidemenuCommon::generate_css('.sidemenu section a:hover', 'color', 'sidemenu_link_hover_color');
            sidemenuCommon::generate_css('.sidemenu section', 'border-bottom-width', 'sidemenu_section_border_width', '', 'px', (get_theme_mod('sidemenu_section_border_width') ? (absint(get_theme_mod('sidemenu_section_border_width')) - 1) : ''));
            sidemenuCommon::generate_css('.sidemenu section', 'border-bottom-color', 'sidemenu_section_border_color');
            sidemenuCommon::generate_css('.sidemenu section', 'border-bottom-style', 'sidemenu_section_border_style');

}

?>
</style> 
<!--/Customizer CSS-->
<?php

        }

	}

    if (!class_exists('sidemenuPremium')) {

        require_once(dirname(__FILE__) . '/includes/class-sidemenu-premium.php');

    }

    function sidemenu_install_standard_notice() {

?>

<div class="notice notice-error sidemenu-notice">

<p><strong><?php _e('SideMenu Premium', 'sidemenu'); ?></strong><br />
<?php _e('In order to use this plugin, you need to install the standard free version ...', 'sidemenu'); ?></p>

<p><a href="<?= esc_url(wp_nonce_url(add_query_arg(array('action' => 'install-plugin', 'plugin' => 'sidemenu'), self_admin_url('update.php')), 'install-plugin_sidemenu')); ?>" title="<?= __('Install SideMenu', 'sidemenu'); ?>" class="button-primary"><?= __('Install SideMenu', 'sidemenu'); ?></a></p>

</div>

<?php

    }

    function sidemenu_premium_init() {

        if (class_exists('sidemenu_class')) {

            sidemenuPremium::start_trial();
            $sidemenu_premium_object = new sidemenu_premium_class();

        } else {

            add_action('admin_notices', 'sidemenu_install_standard_notice');

        }

    }

    add_action('plugins_loaded', 'sidemenu_premium_init');

}

?>
